@@ -1,11 +1,11 @@
 from rest_framework import serializers
 
-from apis_core.apis_vocabularies.serializers import LabelTypeSerializer
+from apis_core.apis_vocabularies.serializers import LabelTypeMinimalSerializer
 from .models import Label
 
 
 class LabelSerializerLegacy(serializers.ModelSerializer):
-    label_type = LabelTypeSerializer()
+    label_type = LabelTypeMinimalSerializer()
 
     class Meta:
         model = Label
